"""
Written by Matteo Dunnhofer - 2019

Class that defines an expert tracker
"""
import os

class DemoTracker(object):

	def __init__(self, cfg, name, dataset):
		self.cfg = cfg
		self.name = name
		self.dataset = dataset

		self.color = None

		self.tracker_path = os.path.join(self.cfg.DATA_PATH, 'results', self.dataset, self.name)

		self.tot_ious = []

	def load_predictions(self, seq_name, init_idx=0, end_idx=-1):
		"""
		Load the predictions of the tracker for the given sequence
		"""
		self.current_seq = seq_name
		
		if 'GOT-10k' in self.dataset:
			f_name = seq_name + '/'+ seq_name + '_001'
		else:
			f_name = seq_name
		
		self.seq_pred_file_path = os.path.join(self.tracker_path, f_name + '.txt')

		with open(self.seq_pred_file_path) as f:
			content = f.readlines()

		self.predictions = []
		self.ious = []	

		for c in content:
			ccs = c.split(',')
			x, y, w, h = float(ccs[0]), float(ccs[1]), float(ccs[2]), float(ccs[3])

			self.predictions.append([x, y, w, h])

		if end_idx > 0:
			self.predictions = self.predictions[init_idx:end_idx]

		return self.predictions

	def get_pred(self, idx):
		"""
		Return the idx prediction of the tracker
		"""
		return self.predictions[idx]

	def add_iou(self, iou):
		"""
		Add the computed iou
		"""
		self.ious.append(iou)
		self.tot_ious.append(iou)


