"""
Written by Matteo Dunnhofer - 2019

Utility functions
"""
from PIL import Image, ImageDraw, ImageFonts

def clip(value, min_value, max_value):
    return max(min(value, max_value), min_value)

def cxcywh2xyxy(bbox):
    x1 = bbox[0] - (bbox[2] / 2)
    y1 = bbox[1] - (bbox[3] / 2)

    return [x1, y1, x1 + bbox[2], y1 + bbox[3]]

def xywh2xyxy(bbox):
    x1 = bbox[0]
    y1 = bbox[1]

    return [x1, y1, x1 + bbox[2], y1 + bbox[3]]

def xyxy2cxcywh(bbox):
    w = bbox[2] - bbox[0]
    h = bbox[3] - bbox[1]
    x = bbox[0] + (w / 2)
    y = bbox[1] + (h / 2)

    return [x, y, w, h]

def xyxy2xywh(bbox):
    w = bbox[2] - bbox[0]
    h = bbox[3] - bbox[1]
    x = bbox[0]
    y = bbox[1]

    return [x, y, w, h]

def get_crop_bb(bb, img_w, img_h, k):
    # compute the coordinates of a padded crop

    w = clip(bb[2], 0, img_w)
    h = clip(bb[3], 0, img_h)

    cx = clip(bb[0] + (w / 2), 0, img_w)
    cy = clip(bb[1] + (h / 2), 0, img_h)

    new_w = k * w
    new_h = k * h

    new_x1 = cx - (new_w / 2)
    new_y1 = cy - (new_h / 2)
    new_x2 = cx + (new_w / 2)
    new_y2 = cy + (new_h / 2)

    #print([new_x1, new_y1, new_x2, new_y2], w, h)
    #crop = [clip(new_x1, 0.0, img_w), clip(new_y1, 0.0, img_h), clip(new_x2, 0.0, img_w), clip(new_y2, 0.0, img_h)]
    #print([new_x1, new_y1, new_x2, new_y2], img_w, img_h)
    #print([clip(new_x1, 0.0, img_w), clip(new_y1, 0.0, img_h), clip(new_x2, 0.0, img_w), clip(new_y2, 0.0, img_h)])
    crop = [new_x1, new_y1, new_w, new_h]
    #print(crop)

    #crop = check_coords_image(crop)

    return crop


def draw_box(img, bbox, color='magenta', width=3):
    """
    Draws a contour onto a slice
    """
    b = xywh2xyxy(bbox)
    draw = ImageDraw.Draw(img)

    c = b
    for _ in range(width):

        c = [c[0] + 1, c[1] + 1, c[2] - 1, c[3] - 1]
        draw.rectangle(c, outline=color)

    return img

def draw_text(img, text, color='magenta'):
    draw = ImageDraw.Draw(img)

    font = ImageFont.truetype("/usr/share/fonts/truetype/ubuntu/UbuntuMono-R.ttf", size=30)

    text_size = font.getsize(text)

    draw.rectangle(((8, 8), (text_size[0] + 12, text_size[1] + 14)), fill="black")

    draw.text((10, 10), text, font=font, fill=color)

    return img
